.. CoTeDe documentation master file, created by
   sphinx-quickstart on Thu Jan  1 20:18:58 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


:tocdepth: 2

#############################################
CoTeDe: Quality Control of Oceanographic Data
#############################################

.. _user-docs:

******************
User Documentation
******************

**CoTeDe at a glance**

.. toctree::
   :maxdepth: 1

   readme
   install
   data_model
   getting_started
   qctests


**Help & reference**

* :doc:`api`
* :doc:`usedby`
* :doc:`history`

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
